// Provide commonly needed information on DECam devices
#include "DECamInfo.h"

#include <fstream>
#include <sstream>
#include "StringStuff.h"

using namespace decam;
using namespace std;

string ccdData =
        "# Information on each DECam CCD, (7 July 2013) \n"
        "#name no. detsecX  detsecY    \n"
        "N1  32   14337     1	  \n"
        "N2  33   14337  4097	  \n"
        "N3  34   14337  8193	  \n"
        "N4  35   14337 12289	  \n"
        "N5  36   14337 16385	  \n"
        "N6  37   14337 20481	  \n"
        "N7  38   14337 24577	  \n"
        "N8  39   16385  2049	  \n"
        "N9  40   16385  6145	  \n"
        "N10 41   16385 10241	  \n"
        "N11 42   16385 14337	  \n"
        "N12 43   16385 18433	  \n"
        "N13 44   16385 22529	  \n"
        "N14 45   18433  2049	  \n"
        "N15 46   18433  6145	  \n"
        "N16 47   18433 10241	  \n"
        "N17 48   18433 14337	  \n"
        "N18 49   18433 18433	  \n"
        "N19 50   18433 22529	  \n"
        "N20 51   20481  4097	  \n"
        "N21 52   20481  8193	  \n"
        "N22 53   20481 12289	  \n"
        "N23 54   20481 16385	  \n"
        "N24 55   20481 20481	  \n"
        "N25 56   22529  6145	  \n"
        "N26 57   22529 10241	  \n"
        "N27 58   22529 14337	  \n"
        "N28 59   22529 18433	  \n"
        "N29 60   24577  8193	  \n"
        "N31 62   24577 16385	  \n"
        "S1  25   12289     1	  \n"
        "S2  26   12289  4097	  \n"
        "S3  27   12289  8193	  \n"
        "S4  28   12289 12289	  \n"
        "S5  29   12289 16385	  \n"
        "S6  30   12289 20481	  \n"
        "S7  31   12289 24577	  \n"
        "S8  19   10241  2049	  \n"
        "S9  20   10241  6145	  \n"
        "S10 21   10241 10241	  \n"
        "S11 22   10241 14337	  \n"
        "S12 23   10241 18433	  \n"
        "S13 24   10241 22529	  \n"
        "S14 13    8193  2049	  \n"
        "S15 14    8193  6145	  \n"
        "S16 15    8193 10241	  \n"
        "S17 16    8193 14337	  \n"
        "S18 17    8193 18433	  \n"
        "S19 18    8193 22529	  \n"
        "S20  8    6145  4097	  \n"
        "S21  9    6145  8193	  \n"
        "S22 10    6145 12289	  \n"
        "S23 11    6145 16385	  \n"
        "S24 12    6145 20481	  \n"
        "S25  4    4097  6145	  \n"
        "S26  5    4097 10241	  \n"
        "S27  6    4097 14337	  \n"
        "S28  7    4097 18433	  \n"
        "S29  1    2049  8193	  \n"
        "S30  2    2049 12289	  \n"
        "S31  3    2049 16385	  \n"
        "# N30 61   24577 12289 dead CCD  \n ";

Bounds<int> decam::datasec(const string detpos, const string amp) {
    if ((detpos[0] == 'S' && amp == "A") || (detpos[0] == 'N' && amp == "B")) {
        return Bounds<int>(1025, 2048, 1, 4096);
    } else if ((detpos[0] == 'S' && amp == "B") || (detpos[0] == 'N' && amp == "A")) {
        return Bounds<int>(1, 1024, 1, 4096);
    } else {
        throw std::runtime_error("datasec() has bad detpos/amp combination " + detpos + "/" + amp);
    }
}

map<string, Device> decam::decamInfo() {
    map<string, Device> info;
    {
        istringstream iss(ccdData);
        string buffer;
        DECamMap map;
        while (getlineNoComment(iss, buffer)) {
            istringstream iss(buffer);
            string name;
            Device d;
            if (!(iss >> name >> d.ccdnum >> d.detsecX >> d.detsecY)) {
                cerr << "Bad Device line: " << buffer << endl;
                exit(1);
            }
            map.setDevice(name);
            Bounds<double> b;
            double x, y;
            map.toField(1., 1., x, y);
            b += Position<double>(x, y);
            map.toField(1., 2048., x, y);
            b += Position<double>(x, y);
            map.toField(1., 4096., x, y);
            b += Position<double>(x, y);
            map.toField(1024., 4096., x, y);
            b += Position<double>(x, y);
            map.toField(2048., 4096., x, y);
            b += Position<double>(x, y);
            map.toField(2048., 2048., x, y);
            b += Position<double>(x, y);
            map.toField(2048., 1., x, y);
            b += Position<double>(x, y);
            map.toField(1024., 1., x, y);
            b += Position<double>(x, y);
            d.b = b;
            d.norm = 1.;
            info[name] = d;
        }
    }
    return info;
}

void decam::getDeviceNorms(string filename, map<string, Device> &devices) {
    ifstream ifs(filename.c_str());
    if (!ifs) {
        cerr << "could not open device norms file " << filename << endl;
        exit(1);
    }
    string buffer;
    while (getlineNoComment(ifs, buffer)) {
        istringstream iss(buffer);
        string detpos;
        double norm;
        if (!(iss >> detpos >> norm)) {
            cerr << "Bad input line in device norm file: <" << buffer << ">" << endl;
            exit(1);
        }
        if (devices.count(detpos) == 0) {
            cerr << "Unknown DETPOS in norm file: <" << detpos << ">" << endl;
            exit(1);
        }
        devices[detpos].norm = norm;
    }
}

DECamMap::DECamMap() : prefix("i/"), pixmap(nullptr) {
    istringstream iss(referenceMap);
    pmc.read(iss);

    // Shift all field coordinates so that center of N4 & S4 is origin:
    Bounds<double> b;
    double x, y;
    pmc.issueMap(prefix + "N4")->toWorld(1024., 2048., x, y);
    b += Position<double>(x, y);
    pmc.issueMap(prefix + "S4")->toWorld(1024., 2048., x, y);
    b += Position<double>(x, y);
    centerX = b.center().x;
    centerY = b.center().y;
}

void DECamMap::setDevice(string detpos) { pixmap = pmc.issueMap(prefix + detpos); }

void DECamMap::toPix(double xField, double yField, double &xPix, double &yPix) const {
    pixmap->toPix(xField + centerX, yField + centerY, xPix, yPix);
    return;
}

void DECamMap::toField(double xPix, double yPix, double &xField, double &yField) const {
    pixmap->toWorld(xPix, yPix, xField, yField);
    xField -= centerX;
    yField -= centerY;
    return;
}

string DECamMap::referenceMap =
        "PixelMapCollection: This is a serialized PhotoMapCollection\n"
        "i/N1:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-1.080887592350013, -2.000340416431544e-07, 7.296385936197251e-05, "
        "-3.186646838709943e-12, -3.934413023107825e-13, -4.855051791145481e-11, 2.035266839343591e-15, "
        "2.711104953493161e-15, -4.790035998094684e-16, 6.21841453832431e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.005189498370479182, -7.303361820837504e-05, -2.093361087334708e-07, "
        "-9.758584211909673e-12, -7.064973570248837e-12, -2.957643925577587e-13, 3.964176816834271e-15, "
        "5.033242376574673e-16, -2.557738940810223e-15, 1.116359079282564e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N10:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3058623710942437, -1.040186472116178e-07, 7.319116218308848e-05, "
        "-3.966294375573985e-12, -8.776363072305883e-12, 1.719646586194387e-11, 2.225042326231902e-15, "
        "-5.549927946523869e-16, -3.256877758384486e-16, -1.184209171495752e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1717424416543587, -7.319741560381973e-05, -1.797048445999643e-07, "
        "-3.537606817862176e-12, -1.34636333391013e-11, 4.660163460316629e-12, 5.56074697720576e-15, "
        "1.537661435268677e-15, 8.339031158438425e-16, 3.600607826227202e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N11:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.005496898628854271, -1.642082503265483e-07, 7.326720509139309e-05, "
        "-2.641219417352464e-12, -5.1150992395764e-12, -8.713985194620786e-13, 2.387340194994406e-17, "
        "-3.08955689018304e-16, -1.153847599792043e-15, -1.3206176678078e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1726303628392537, -7.323649568351885e-05, -1.593693627988225e-07, "
        "5.051109282431387e-12, 4.916381412288169e-12, 1.316380572792585e-12, 3.800870724279441e-15, "
        "-7.117875265943496e-16, 7.339920354937881e-16, 5.122969683454849e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N12:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3167682003994335, -1.95039788369341e-07, 7.318195127586619e-05, "
        "-8.047810459988896e-12, -8.396534722446836e-12, -2.041575514783883e-11, 1.108979257664374e-16, "
        "-6.846542550722454e-16, 7.220350990213601e-16, -7.581973144263231e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1732860683233148, -7.320673009165662e-05, -1.30664121248613e-07, "
        "8.505925541303753e-12, 1.520994011278965e-11, 3.01185907416732e-12, 1.803694556091886e-15, "
        "-5.927219385333272e-16, 6.848068971402479e-16, -5.182919020199073e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N13:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6272674252891635, -2.233271999757154e-07, 7.299143719062181e-05, "
        "-1.446293102580458e-11, -5.101761626813577e-12, -4.001103973005705e-11, 1.827497287790057e-15, "
        "1.91361663656415e-16, 2.018867786148009e-15, 3.600506068707415e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1738522783860524, -7.31341925368067e-05, -1.270875320844976e-07, "
        "6.290587888442824e-12, 2.584508670853046e-11, 6.374224850327174e-12, 1.974102661035407e-15, "
        "-9.622260064486458e-16, -1.61971708500883e-15, -9.810950369904122e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N14:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.9266720867969531, -6.405080999236855e-08, 7.285894793389396e-05, "
        "-9.346773419181026e-12, 1.936688766995508e-11, -1.53381833240826e-12, 2.442130926339741e-15, "
        "2.816765221704866e-15, -3.815733661167369e-15, 2.61918233759561e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3342381884607208, -7.301162661053186e-05, -2.03533700932916e-07, "
        "-8.357289031038732e-12, -6.469199150900561e-12, -1.052722237793139e-11, 4.007921455684706e-15, "
        "3.62378851200963e-15, -2.164711906930966e-15, 1.41869386420225e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N15:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6170987131309598, -5.399283004979326e-08, 7.297354726056889e-05, "
        "1.311538735298795e-11, -2.95086159279997e-12, 2.497583408322456e-11, -2.186795581816958e-15, "
        "-6.349452090673035e-17, -1.797849951462812e-15, -2.436247715660574e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3353645088569879, -7.307530747209949e-05, -2.349612692536525e-07, "
        "1.333204534096845e-11, -1.895922185271631e-11, 7.589341674672642e-13, 5.269711570731263e-16, "
        "2.307125861751155e-15, 1.437648962152077e-16, 6.935884057198733e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N16:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3061596671739321, -1.412180790348547e-07, 7.317702032848944e-05, "
        "8.877781809040544e-12, -1.339790012966743e-11, 9.76397023353717e-12, -2.016095873837939e-15, "
        "-1.395754823785043e-16, -6.232353961426977e-16, -3.524605176916534e-17]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3363657280939634, -7.313422216385058e-05, -2.534228917185538e-07, "
        "9.98229904644856e-12, -9.447343768669804e-12, 6.941301366738503e-12, 3.600016985906997e-15, "
        "1.379460631613312e-15, 5.586314920822311e-16, 1.504254690996269e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N17:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.004757690832383524, -1.402348838146023e-07, 7.324189813017345e-05, "
        "-3.680324655206102e-12, -1.774673031692822e-11, 3.899511218321692e-12, 1.323284283550417e-15, "
        "-1.383296456155692e-15, 9.054388847958866e-16, -2.526729084397236e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3373631081391986, -7.31628257372976e-05, -1.487133438741075e-07, "
        "1.48559608269421e-11, 3.574671699753387e-12, 1.047048441620882e-11, 3.495162753461511e-15, "
        "-3.88014572147506e-16, 6.143493527635605e-16, -4.46117720367013e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N18:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3162672426704817, -2.377143442132253e-07, 7.315371792149757e-05, "
        "-1.284646495124735e-11, -1.152588829082061e-11, -1.571552437472113e-11, 3.218754020219357e-15, "
        "-1.035746173931356e-15, 9.305398358257947e-16, -1.252599495172675e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3378320630109476, -7.313808383105469e-05, -1.1658158894493e-07, "
        "2.021101158673642e-11, 1.095731675328002e-11, 7.320258894909632e-12, 6.595616588774644e-16, "
        "-1.386387043668722e-15, 1.017893574397383e-15, -5.616611544841797e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N19:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6267603748015954, -2.654817103253404e-07, 7.298204592140393e-05, "
        "-1.302916412196466e-11, -8.322389482560725e-12, -3.760824784367237e-11, 2.060448403957085e-15, "
        "1.968780256580216e-15, 3.967313972295696e-15, 4.078755667210575e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3381652980472313, -7.307844680342281e-05, -8.087581243380146e-08, "
        "1.256480049902161e-11, 2.510237335004395e-11, 6.806858246254242e-12, 1.474465429454199e-15, "
        "-2.816267679989774e-15, -2.770498567461665e-15, -1.574879083444148e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N2:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.7711734869916769, -1.752542734033194e-07, 7.286843702623423e-05, "
        "7.54482978457982e-12, -2.726878034662652e-12, 2.933980884870653e-11, 1.450727950981055e-15, "
        "-5.895436680084744e-16, 4.627972571689856e-16, -3.55779841332424e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.005922469265715206, -7.311258847846686e-05, -1.90851768710988e-07, "
        "-2.112942463006409e-12, -2.141628188135668e-11, 1.308283040616808e-12, 2.614118756161886e-15, "
        "-2.441165369498065e-16, 2.376691091028221e-16, -1.562110211390834e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N20:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.7718282693846102, -8.587590978314309e-08, 7.291015661025128e-05, "
        "4.624090583365187e-12, 1.341178089430409e-11, 7.461774956354477e-12, -1.79932973396982e-15, "
        "5.335023231991858e-16, -3.092311354458243e-15, 1.740915800669248e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.4990454341671942, -7.29949523001736e-05, -3.041251569774419e-07, "
        "2.633983204221773e-12, 2.704503897724109e-12, -5.651441950306172e-12, 2.671219286282044e-15, "
        "2.168004549393812e-15, -1.732331254631042e-15, 1.137809889729941e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N21:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.4617590052883465, -5.814468988485123e-08, 7.304681422348989e-05, "
        "6.571566941408301e-12, -1.184904998672673e-11, 2.254267755804973e-11, -1.891630272407217e-15, "
        "5.376945441015924e-16, -1.793925106752923e-15, -7.562650707986055e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.5002122917808792, -7.302187432056448e-05, -2.744227255182691e-07, "
        "2.050393805233038e-11, -6.421900878668479e-12, 6.875774524166923e-12, 5.946030088958537e-16, "
        "1.024929900737313e-15, -3.110469898388402e-16, 4.41847273861537e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N22:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1508139491262396, -1.376228453122049e-07, 7.318165988744059e-05, "
        "-8.199197726810961e-13, -2.039526265532237e-11, 1.096365484773051e-11, 1.128718169985872e-15, "
        "-1.021488927325219e-15, 1.20015249296697e-16, -1.733385030755952e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.5011584084851145, -7.304560778453134e-05, -2.246006136150637e-07, "
        "1.209180580276959e-11, -1.511236730210244e-12, 1.157775746148162e-11, 5.171548124236378e-15, "
        "4.526041994120929e-16, 3.104222499115501e-16, -8.596884408485228e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N23:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1601824556062395, -2.312426732385882e-07, 7.319651571556335e-05, "
        "-1.235784944131488e-11, -1.869199097628447e-11, -2.110605645962155e-11, 3.161715679199656e-15, "
        "-1.787917057079472e-16, 5.554741955059555e-16, 9.231515844362162e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.5020905838930528, -7.30520810866889e-05, -1.516698325953901e-07, "
        "2.405542269751473e-11, 8.683148373223557e-12, 8.953375179654529e-12, 9.129887496931143e-16, "
        "-4.485414779405755e-16, -5.865223583702804e-16, 6.807155588239264e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N24:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4709226353681134, -2.82689244817782e-07, 7.305352447413507e-05, "
        "-4.968460414379285e-12, -1.715261034191177e-11, -2.827718905824799e-11, 1.466532922878584e-17, "
        "2.510001010761512e-15, 3.741375081962266e-15, 1.567886957916486e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.502423283156014, -7.302157391990772e-05, -6.966616070258767e-08, "
        "2.20312444833961e-11, 2.042130498252796e-11, 9.897852417665048e-12, -4.627337541148624e-17, "
        "-3.866555134850801e-15, -3.028397758059639e-15, -1.188275286767699e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N25:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6169512394669354, -6.446447499544062e-08, 7.29767528734442e-05, "
        "-1.01125992914892e-12, 6.23100616878727e-12, 7.632567272017907e-12, -2.41188765361385e-15, "
        "1.553457434949364e-15, -3.604343805475045e-15, 1.218711898965092e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6637754335502292, -7.293511304104768e-05, -3.130296025102426e-07, "
        "3.571523500723962e-12, 1.285735424916502e-11, -1.011977771989876e-13, -1.317527063239267e-15, "
        "5.319629714894011e-15, -3.386523585221304e-15, 1.076245069462011e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N26:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3067707008263768, -8.433915445827497e-08, 7.308003332927377e-05, "
        "2.035666113078819e-12, -1.775012880874097e-11, 2.28950871193728e-11, -7.554826546758827e-16, "
        "2.747845045967048e-17, -7.012038222352127e-16, -2.515952348075964e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6649544756278832, -7.292694233667481e-05, -2.575049460559259e-07, "
        "2.02367962675657e-11, 1.279159254725306e-12, 9.476012268355706e-12, -1.271522193879125e-15, "
        "1.610248486493579e-15, -6.295504934097307e-16, 4.168447093466529e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N27:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.004147865608792798, -1.201509938354096e-07, 7.316286277576282e-05, "
        "-1.357300301992904e-11, -2.236361320776812e-11, -3.774358684540594e-12, 3.851654546816602e-15, "
        "6.475302681437575e-16, -4.647448520927542e-17, -6.796178469702011e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6660042248900183, -7.293576032509382e-05, -1.277064713095147e-07, "
        "2.675044246865456e-11, 4.687117747547623e-12, 1.182592945456431e-11, -1.181706486646703e-15, "
        "-1.134004302452009e-15, -7.581243791850569e-16, 9.185852446528574e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N28:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.314900451095264, -2.292887081588894e-07, 7.309781321850399e-05, "
        "-7.301176093317223e-12, -3.026964873121852e-11, -1.925648190556108e-11, 1.712759483146422e-15, "
        "2.896261662234054e-15, 4.573069494587011e-15, 3.971658157604075e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.666419129264228, -7.293306403825411e-05, -7.286557062446877e-08, "
        "2.402964861441086e-11, 1.271543695814046e-11, 1.65588423929397e-11, -1.414820563940244e-15, "
        "-3.964788179783218e-15, -3.278592285214032e-15, -1.597030541171469e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N29:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.461967827516221, -1.037988716926319e-07, 7.301778211405859e-05, "
        "-1.191636270361182e-11, -3.472635128761477e-12, 4.129972788625784e-12, -2.170109841133801e-15, "
        "4.154678236381782e-15, -2.808305834368684e-15, 1.235216640937506e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.8283939382704693, -7.287957796383745e-05, -3.040029656947395e-07, "
        "-9.256868429854766e-12, 2.442948547838253e-11, 2.314379899652461e-12, -2.551145729389327e-15, "
        "3.825240504065084e-15, -3.457402372860182e-15, 8.294517314908811e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N3:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.4609958843249758, -1.542688073331085e-07, 7.310827116519653e-05, "
        "1.711050552580769e-11, -4.972159432581978e-12, 2.062000592883159e-11, -3.034432811176215e-15, "
        "-5.99780674319598e-16, 4.762480179458635e-16, -1.779297809836328e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.006741802094304757, -7.319263438106786e-05, -1.561635287135403e-07, "
        "-1.329379051354901e-11, -1.691913132916958e-11, -1.978419606804287e-13, 6.216634242883045e-15, "
        "-1.061019257645827e-16, 8.668631885774625e-16, 1.886702583813875e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N31:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1592521018011679, -2.32883871997166e-07, 7.309893337649252e-05, "
        "-5.477123823540179e-12, -3.176861204989547e-11, -1.351688651471203e-11, 2.25880264314362e-15, "
        "3.378489390745434e-15, 3.939398023076399e-15, 4.949459451591926e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.8302084791650062, -7.2833609628207e-05, -1.552615716035761e-07, "
        "6.776112403780141e-12, 9.215170533637029e-13, 1.527838558556199e-11, -3.117330077768425e-15, "
        "-3.036109445569725e-15, -3.015000394876986e-15, -1.249657100940715e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N4:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1498867838505598, -1.741809070378398e-07, 7.326046314656055e-05, "
        "4.593922746556033e-12, 1.112157755853706e-13, 4.977237412305955e-12, -6.466617195254388e-16, "
        "-1.256727200520386e-15, -2.117522265841847e-16, -6.531829454783384e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.007421871509847679, -7.324578804713373e-05, -1.711393868836424e-07, "
        "-1.032369298919553e-11, -6.288382604218625e-12, 1.64895463515254e-12, 4.379506380417516e-15, "
        "9.02987350568066e-16, 8.643431022133132e-16, -1.990225766042639e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N5:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1612874926952429, -1.26210289353258e-07, 7.326629772164255e-05, "
        "1.12806101006017e-12, 4.152207134389224e-14, -1.738861596618102e-11, -1.319527895546389e-15, "
        "-1.876189826628709e-15, 3.349722966600754e-16, -5.570138065375262e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.008331351604459447, -7.325452232281694e-05, -1.156976482855576e-07, "
        "-5.340174545651298e-12, 9.463530084227803e-12, 1.602018965471137e-12, 3.506792751984973e-15, "
        "2.163434997291031e-16, 9.358596477742509e-16, -2.165097523066417e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N6:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4724716285230381, -1.72492656425301e-07, 7.3104707336836e-05, "
        "-1.398152195152609e-11, -1.675470064818831e-12, -3.547343184724051e-11, 1.348120068689558e-15, "
        "-2.300578749581937e-16, 3.215728167262725e-16, 1.233736651896836e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.008829240568281079, -7.320782704406423e-05, -1.68002331452738e-07, "
        "5.11187204709569e-12, 2.317010015419892e-11, 1.133145971164097e-12, 7.61474172461114e-16, "
        "-1.164452966296209e-15, 2.135256206686768e-16, -1.352288762078348e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N7:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.7827661037166128, -1.874811740217032e-07, 7.286747901060057e-05, "
        "-2.535936101498048e-11, -1.250837113241967e-12, -1.988778551394648e-11, 4.536248234730925e-15, "
        "2.203484103118984e-15, 2.131316434519316e-16, 4.363138231057233e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.009611939319485219, -7.310747164697113e-05, -1.877535284790552e-07, "
        "-4.176646579355371e-13, 2.735618259437461e-11, 2.266727143588997e-13, 1.878644279946344e-15, "
        "-1.062480895389345e-15, -1.979499401567102e-15, -5.141351108510149e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N8:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.9263619169923072, -1.110429033803103e-07, 7.282959283409226e-05, "
        "9.714705893231394e-13, 1.454589544236197e-11, 3.146920983256502e-12, 2.742369260516751e-15, "
        "2.187687623260629e-18, -2.305574603445448e-15, 2.50233364732161e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1700434713941772, -7.305057598453837e-05, -1.899942237994179e-07, "
        "2.553537355020133e-12, -1.990359700194664e-11, -3.392921876197986e-12, 1.105341055010262e-15, "
        "2.513545614913721e-15, -6.340736221085263e-16, 3.311188810249516e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/N9:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6166453135612863, -1.067336952593741e-07, 7.298298322856482e-05, "
        "1.764789271896622e-11, -1.687841590225423e-12, 2.666957677906258e-11, -2.840034607132184e-15, "
        "-6.390825286368418e-16, -8.826364773260198e-16, -3.142646491944643e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1709689454332172, -7.313578460497193e-05, -1.999438663591678e-07, "
        "5.752343238487408e-12, -1.924955771004262e-11, 6.39862113351272e-13, 2.730870222175082e-15, "
        "3.565738018408999e-16, 3.985605643435757e-16, 3.984768294060378e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S1:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-1.080386562109725, -1.70891027462497e-07, 7.296693751054784e-05, "
        "-5.113560963109399e-12, -6.504915324288201e-12, -4.584643106127036e-11, 2.646208563601488e-15, "
        "2.134920033371888e-15, -3.577249178229373e-16, 5.663577868347015e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1589722794799351, -7.302583728240832e-05, -1.382216347464105e-07, "
        "-9.189304173463705e-12, -8.850646832702328e-12, 4.160490165290149e-12, 2.556453210792804e-15, "
        "-1.470230741691605e-17, -1.784071676533282e-15, -9.632837607081166e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S10:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3045926979721047, -2.35153929227662e-07, 7.317475056305213e-05, "
        "1.200639895502934e-11, 1.344305541008294e-11, 1.715664805797993e-11, -1.74870338369303e-15, "
        "-1.410449389032354e-15, -4.374734151430625e-17, -1.45029734968852e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.322464009835286, -7.315044372628114e-05, -1.120322465379516e-07, "
        "-2.204383646827783e-11, -1.346315260446105e-11, -6.547709108007847e-12, 2.444715549638706e-15, "
        "-1.868724477738874e-16, 1.802640163329885e-15, -1.444855152413951e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S11:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.00666286716138522, -2.014675063168545e-07, 7.324726000927942e-05, "
        "2.695135142958762e-12, 1.208241266868092e-11, -5.831408778091474e-13, -1.115616814670874e-15, "
        "-1.450558112098968e-15, 3.114026854140496e-16, -1.547812855954327e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3219573957152201, -7.317248444783644e-05, -2.026217863009826e-07, "
        "-2.838838601809686e-11, 3.407958528021834e-12, -5.290595207170122e-12, 4.369890275859327e-15, "
        "-6.960107952253394e-16, 1.280954710479423e-15, -1.81272241476962e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S12:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.318025276108985, -1.259937884476299e-07, 7.317249741906958e-05, "
        "-8.295418116986189e-12, 5.316271326814942e-12, -2.020362294123536e-11, 5.314229702900953e-16, "
        "-8.118613870366457e-16, 4.665673573224426e-16, -9.794281453956526e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3209958480361266, -7.314745066626274e-05, -2.462798906150329e-07, "
        "-2.445112833832747e-11, 1.151614342384538e-11, -2.763166959107477e-12, 3.944167901793549e-15, "
        "-1.543715184610506e-16, 1.348098833134469e-15, -2.728886364447539e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S13:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6284566429398994, -9.323721683268165e-08, 7.29603207389235e-05, "
        "-8.798288779723928e-12, 2.122157710520578e-12, -2.561177948407627e-11, -5.925535195308361e-16, "
        "6.544041208400148e-16, -1.701051824558878e-15, 2.296765860353194e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.319868472743803, -7.307581475280021e-05, -2.706181272652896e-07, "
        "-2.559863186780224e-11, 1.745917170784354e-11, -2.514259832950984e-12, 4.090230470871295e-15, "
        "1.447222019872215e-15, -5.884260936342549e-16, 7.350973242441429e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S14:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.9243293688774294, -2.43176759278631e-07, 7.293470127267584e-05, "
        "-7.503007374938648e-12, -2.89227333432666e-11, -2.124927991889512e-11, 2.414201710419031e-15, "
        "1.969140496068039e-15, 3.753274551455051e-15, 4.171423586522868e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4872558429184541, -7.299516583755586e-05, -1.130865086718176e-07, "
        "-1.386207050608653e-11, 6.732225785099932e-12, 1.473547265866624e-11, 2.562609218694625e-15, "
        "-2.754985660750862e-15, -2.256824130051201e-15, -1.306768215688507e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S15:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6145572208901259, -3.140362104233508e-07, 7.295203875523631e-05, "
        "4.431232008231587e-12, 1.319373976082169e-11, 2.57856374616593e-11, 1.42706446465903e-15, "
        "-1.180357070270088e-15, -1.643924098282748e-16, -3.737910013950478e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.487179499439978, -7.299750961205489e-05, -4.828347315102745e-08, "
        "-2.884548265916738e-11, -1.5395697547198e-11, -6.943514574006783e-12, 3.06973540956352e-15, "
        "-8.56238816379137e-16, 1.050858906119853e-15, -2.353394097763972e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S16:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3040111519865074, -2.51774219960162e-07, 7.314943792597962e-05, "
        "9.097172146776798e-12, 1.839649603082332e-11, 1.108470139078204e-11, -1.658841067867516e-15, "
        "-1.247026877385794e-15, 1.170690529138066e-16, -5.167275401968146e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.48696691124687, -7.30503249622622e-05, -9.177964264280631e-08, "
        "-3.09097643183575e-11, -6.781630214311113e-12, -9.866037915126212e-12, 2.368183633498514e-15, "
        "-1.283760776522667e-16, 6.247258611748037e-16, 1.499434111604133e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S17:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.007013822612119993, -1.601497809671191e-07, 7.32219156482915e-05, "
        "7.038003803274951e-12, 1.662806078263747e-11, -4.959715613695202e-12, -2.882015952158683e-15, "
        "-4.090165589826114e-16, 1.433559559868114e-17, -9.020958338483546e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4861459146100904, -7.305761395103388e-05, -1.58992607998137e-07, "
        "-4.417141915243993e-11, 4.736018054283819e-13, -8.151830531757754e-12, 6.88832385046002e-15, "
        "3.361249186021522e-16, 8.971841224710121e-16, -1.928287786346339e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S18:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3180966090082141, -1.242150307594014e-07, 7.313956493720552e-05, "
        "-8.091965860803721e-12, 1.638356277924907e-11, -2.082555985115329e-11, 5.32664578790521e-16, "
        "-1.182127346845103e-16, -1.285223965916223e-15, -2.878038196444001e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4854823758391204, -7.303629503448728e-05, -2.761606089388065e-07, "
        "-4.427734215831737e-11, 1.017455600576945e-11, -9.27578083238066e-12, 7.011317024553628e-15, "
        "1.515473271749139e-15, -1.750363930027993e-16, 5.724080315923313e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S19:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6286829682164544, -2.606716677102972e-08, 7.295630033894031e-05, "
        "-4.403989719653536e-12, -1.338364814174818e-12, -2.165388274651688e-11, -1.96278164094548e-15, "
        "2.702144944284011e-15, -3.420673326394151e-15, 2.85436938639556e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4840973437704917, -7.300623940280158e-05, -2.736762859775041e-07, "
        "-2.512342178242428e-11, 1.507912602948291e-11, -2.170023047257827e-14, 2.733892716904352e-15, "
        "1.993834790849795e-15, -2.667085924955332e-15, 1.160615446690168e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S2:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.7706522067859997, -2.281257907239973e-07, 7.285837756264917e-05, "
        "8.725304346853107e-12, 5.76363142701107e-12, 3.146236818071484e-11, 9.514869219706968e-16, "
        "-9.695972934414551e-16, -2.395423622296629e-16, -6.208286256969581e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.158627873641449, -7.309174531743801e-05, -1.193325451841706e-07, "
        "-6.268789175820742e-12, -2.688220647620513e-11, -1.354037940573761e-12, 3.819804977061407e-16, "
        "2.213575548054677e-17, 1.02525903541712e-15, -1.71555396629997e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S20:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.7687426164129635, -2.391623475413674e-07, 7.293787850832991e-05, "
        "-8.396094192204376e-12, -2.344074243804391e-11, 3.586634027575664e-12, 1.299319601931663e-15, "
        "1.449418534748487e-15, 4.431146135275802e-15, 1.17431031808816e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6513007870378253, -7.296096143780383e-05, -4.661103153276484e-08, "
        "-4.860614481908396e-12, 1.30078548612948e-11, 1.214549125553597e-11, -1.02373916916505e-15, "
        "-2.597497419786303e-15, -2.126896219968267e-15, -1.574662391298192e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S21:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.4585812302426794, -3.393966508945695e-07, 7.302788336975695e-05, "
        "-3.358806336514521e-13, 1.509194485889195e-11, 2.094286596205585e-11, 1.223525496865009e-15, "
        "-4.643805835083846e-16, 6.504107111656264e-16, -1.072228850669012e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6513387639458266, -7.292783793859364e-05, -8.770225789773248e-08, "
        "-2.573534187021398e-11, -5.508418072597767e-12, -7.858008213147556e-12, 1.470134717575916e-15, "
        "-1.466313968847829e-15, 6.910859855608815e-16, -3.167947336786285e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S22:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1480106919907891, -2.133280756439099e-07, 7.314714401326367e-05, "
        "3.198723436682724e-12, 2.111762854264483e-11, 5.838008367431041e-12, -4.326915566595016e-16, "
        "-8.869534377979065e-16, 5.69401962251523e-16, -8.56642603686078e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6507930373860954, -7.293136216667875e-05, -1.153551095546502e-07, "
        "-4.032961526047241e-11, -3.307793012799899e-12, -1.211225532415039e-11, 3.629762643466619e-15, "
        "9.707253428341695e-17, 8.011688235176336e-16, -6.82391755000617e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S23:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1628318890029176, -1.361843569894953e-07, 7.313174476082938e-05, "
        "-5.882021866812685e-12, 2.453114453529563e-11, -3.498712220116119e-12, 1.534944832799337e-15, "
        "-6.369604125038202e-16, -1.608591165817613e-15, -1.545031814935976e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.650156206082033, -7.293178803801261e-05, -2.332122168267197e-07, "
        "-3.726343468017157e-11, 1.487714076676406e-12, -1.125587609216067e-11, 2.552461327555257e-15, "
        "2.010940213513893e-15, -2.541071308605404e-16, 4.11566522713579e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S24:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4735359205315684, -7.468098873021973e-08, 7.303373279453152e-05, "
        "-1.231703172177653e-13, 8.752568907211695e-12, -2.30969076019636e-11, -1.73248733201952e-15, "
        "1.758655830698605e-15, -3.401579140273445e-15, 1.778916647640965e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.6489672979009709, -7.293554917065023e-05, -3.212054658475176e-07, "
        "-2.249503400278227e-11, 1.758056127644694e-12, -3.468687328582692e-12, -3.027543330203041e-16, "
        "4.146249060076411e-15, -2.118860586106866e-15, 1.044512046232918e-15]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S25:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.613132958559433, -2.640307883649622e-07, 7.299313973179011e-05, "
        "-2.257577947062895e-11, -1.533576766701896e-11, 2.402069308231369e-12, 3.699397603314177e-15, "
        "2.646996780363178e-15, 3.577641072483662e-15, 1.154559626309281e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.8154188189012598, -7.293405292006215e-05, -9.591180808954798e-08, "
        "4.46087263022818e-12, 2.997031783974942e-11, 6.387162223295543e-12, -1.82136246565005e-15, "
        "-4.137826425246347e-15, -2.868082204538121e-15, -9.300483649207963e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S26:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.3027798361667181, -2.357177503118181e-07, 7.30572466686623e-05, "
        "2.186786154398831e-12, 1.473442971338921e-11, 1.432976823204521e-11, -9.480459248145998e-16, "
        "3.868174006744194e-17, 1.414075569414333e-15, -1.50699492295788e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.8151079711455629, -7.284129449701148e-05, -5.810429780657943e-08, "
        "-2.185257354090014e-11, 1.7022265932638e-13, -8.872930590336192e-12, 4.00703810786719e-16, "
        "-4.050671380683367e-17, 8.012132015610908e-17, -3.939346226989046e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S27:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.007905658154310873, -2.003756604641082e-07, 7.310395481423238e-05, "
        "1.609507518802418e-12, 2.564650188354178e-11, 4.65467295432773e-12, -6.981572794898706e-16, "
        "5.287559344416544e-17, -1.312779333034365e-15, -1.80550707763059e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.8146334834981825, -7.282917922922381e-05, -1.97586546285407e-07, "
        "-3.130396387874461e-11, -3.021019328240937e-12, -1.303794396747671e-11, 2.365654251449691e-15, "
        "1.538197954930216e-15, -3.735503791998346e-16, 4.119812369466949e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S28:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3184130295495463, -7.178440292319175e-08, 7.308297372821305e-05, "
        "-7.912820879568657e-13, 7.801554580872782e-12, -2.352147770905921e-11, 5.516525932126413e-16, "
        "1.607912118746361e-15, -1.616925171098919e-15, 1.935725267821559e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.8135983519310162, -7.284654148857234e-05, -2.522549423321306e-07, "
        "-2.535702937636683e-11, -7.826045053518655e-12, -6.72939245090379e-12, 2.339365785516948e-15, "
        "3.810022776741728e-15, -2.187829927755678e-15, 9.378485406330927e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S29:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.4574598546912779, -2.079667882750412e-07, 7.301245616873749e-05, "
        "-1.838902596663133e-11, -8.870967713046527e-12, 1.174122840270009e-11, 1.053532122529414e-15, "
        "2.693785514858326e-15, 2.619980948478759e-15, -1.147917583787236e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.9792278748457738, -7.295322795962948e-05, -1.324257223933935e-07, "
        "2.576465568633994e-11, 3.696656140242055e-11, 4.519015095007464e-12, -2.310198007641626e-15, "
        "-4.0807795233428e-15, -2.615187805902266e-15, -9.129581773848978e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S3:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.460423227629549, -2.272258708624925e-07, 7.308494345049436e-05, "
        "7.707660859789764e-12, 7.707234981564763e-12, 2.949632008809923e-11, 4.177277357180516e-16, "
        "-1.72116932268049e-15, -6.355586896638729e-16, -1.325612862801756e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1579420602858603, -7.317538502193811e-05, -1.471073583466092e-07, "
        "-1.484293135180972e-11, -2.066908163054036e-11, -3.184055495134081e-12, 2.502909154407966e-15, "
        "9.957554393010326e-16, 1.284677093406921e-15, 3.50680582926813e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S31:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1635557528617087, -1.609262821554849e-07, 7.305279796572398e-05, "
        "1.473712970490158e-11, 1.461507225972222e-11, -2.491690084101896e-12, -3.028562408037867e-15, "
        "1.952701895844846e-15, -2.641142430328608e-15, -1.472554254085671e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.9780250761701745, -7.285253149778476e-05, -2.139704091141329e-07, "
        "1.828291740265784e-11, -1.463599584956946e-11, -7.536254163983023e-12, -5.333897505687038e-15, "
        "3.541713550663291e-15, -2.370986603978827e-15, 9.583734163948524e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S4:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.1492035116720161, -1.701097036013067e-07, 7.325081543724898e-05, "
        "7.580494524467624e-12, 5.247306326309669e-12, 8.51755137545602e-12, -1.511397620859946e-15, "
        "-1.216620634160714e-15, 1.173239077564533e-16, -1.404683879205795e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1574061351453422, -7.323779378890177e-05, -1.369318804920278e-07, "
        "-1.01250723578048e-11, -5.023088969188544e-12, -2.911297758824426e-12, 1.566644702338738e-15, "
        "-1.526250109950302e-16, 1.436220696362589e-15, -3.949093878937523e-17]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S5:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1619429506116326, -1.456085169929366e-07, 7.325420549589657e-05, "
        "-2.718920111842929e-12, 1.011827139847832e-11, -1.442427404780418e-11, -2.273718004007721e-16, "
        "-1.982345856351556e-15, -1.040869208175208e-15, -8.334400313225868e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1565260854018367, -7.322622690288431e-05, -1.693225826648364e-07, "
        "-2.123937125780179e-11, 7.167108263987614e-12, -4.507458187229225e-12, 5.112528012596503e-15, "
        "-1.92775880885791e-17, 1.537371345344042e-15, 2.778041638641578e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S6:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.4732048837621593, -1.262751792155799e-07, 7.309050089030449e-05, "
        "-9.481005975757553e-12, 3.438941101202226e-12, -2.781932216258941e-11, 2.509392101707172e-16, "
        "-9.599356932748799e-16, -3.440640716720395e-17, -1.541344491299487e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.1557213778785626, -7.316804579558609e-05, -2.035444920953726e-07, "
        "-2.095567210413158e-11, 1.626543786554383e-11, 5.897065737731944e-13, 4.639124406928972e-15, "
        "9.204907602362861e-16, 7.689500365325218e-16, -3.716686984155858e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S7:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.7831890463215312, -9.591316848336283e-08, 7.288622792575091e-05, "
        "-1.414655515930184e-11, -7.451871052242572e-12, -2.695706992426778e-11, 2.326835784416407e-16, "
        "2.540231070603986e-15, -2.762427839729321e-16, 5.525258539614908e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.154936375876974, -7.308730469130235e-05, -1.942150382050308e-07, "
        "-1.209892714092646e-11, 2.16702965660293e-11, 1.90276527528772e-12, 1.946830908362591e-15, "
        "2.494000981227641e-15, -2.365252859624369e-15, 3.777899456958087e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S8:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.9247677494892599, -2.288530019392439e-07, 7.287055766577727e-05, "
        "5.203644613577477e-13, -1.279246369919497e-11, -8.00619768889802e-12, 2.310955184496877e-15, "
        "2.998610282888185e-16, 2.016586303950082e-15, 3.378604663955252e-15]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3232185944522248, -7.302362730473989e-05, -9.193881042442206e-08, "
        "-1.0137057048209e-11, -9.865859941873117e-12, 7.618926600309754e-12, 1.198154875761906e-15, "
        "-1.521489665561555e-15, -1.191416162495372e-15, -7.870589129162571e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S9:\n"
        "  Type: Poly\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [-0.6151529732625216, -2.848234766610437e-07, 7.296580828023611e-05, "
        "9.452844040650614e-12, 8.197296161435135e-12, 3.025342583184091e-11, 5.120976025762183e-17, "
        "-7.651739739341007e-16, 3.203404210933293e-17, -9.915424012094029e-16]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 3\n"
        "    Coefficients: [0.3227366625731989, -7.308712310054212e-05, -9.717453925065121e-08, "
        "-2.015191088805773e-11, -1.879647820129252e-11, -2.44418401010314e-12, 3.310142027465697e-15, "
        "-9.319100902343877e-16, 7.368511070047086e-16, -2.856272438848056e-16]\n"
        "  Tolerance: 2.777777777777778e-07\n"
        "i/S30:\n"
        "  Type: Poly\n"
        "  XMin: 0\n"
        "  XMax: 2048\n"
        "  YMin: 0\n"
        "  YMax: 4096\n"
        "  XPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 4\n"
        "    Coefficients: [-0.000155437828572018, -0.0001437504343508079, 0.1496667310315645, "
        "-1.829694462186668e-06, 4.211186216400162e-05, -3.04237196189354e-06, -1.25893696620853e-07, "
        "3.785641258383692e-06, -6.371748141633215e-08, -5.847496969497692e-06, 1.025354543160702e-06, "
        "-1.154967845858867e-06, 1.871933903472734e-06, -1.180670840351436e-06, 2.143233635156651e-06]\n"
        "  YPoly:\n"
        "    SumOrder: true\n"
        "    OrderX: 4\n"
        "    Coefficients: [0.903916844338849, -0.07457766273054559, -0.0002909575943165279, "
        "2.55403660966221e-06, 3.272672069209499e-06, -4.700109362290156e-05, -8.087698234152517e-06, "
        "3.630898322294715e-08, -9.132918177953053e-06, 8.402166242876431e-07, -1.076476523995879e-06, "
        "-1.357366776943062e-06, 1.852514910369153e-06, -2.300614949515851e-06, 1.674322168189385e-06]\n"
        "  Tolerance: 2.777777777777778e-07\n";
// Last entry for S30 taken from allsf.gut.astro solution, different from others.
/*
  "i/S30:\n"
  "  Type: Poly\n"
  "  XPoly:\n"
  "    SumOrder: true\n"
  "    OrderX: 3\n"
  "    Coefficients: [-0.6151529732625216,
  -2.848234766610437e-07, 7.296580828023611e-05, 9.452844040650614e-12, 8.197296161435135e-12, 3.025342583184091e-11,
  5.120976025762183e-17, -7.651739739341007e-16, 3.203404210933293e-17, -9.915424012094029e-16]\n" " YPoly:\n"
  "    SumOrder: true\n"
  "    OrderX: 3\n"
  "    Coefficients: [0.3227366625731989, -7.308712310054212e-05, -9.717453925065121e-08,
  -2.015191088805773e-11, -1.879647820129252e-11, -2.44418401010314e-12, 3.310142027465697e-15,
  -9.319100902343877e-16, 7.368511070047086e-16, -2.856272438848056e-16]\n" "
  Tolerance: 2.777777777777778e-07\n";
*/
/// Above is old dummy for S30 is just a copy of S9.
